@@ -27,7 +27,7 @@ class NumpyFile(File):
         """
         return np.load(self.path)
 
-    def write(self, data: Any) -> None:
+    def write(self, data: Any, **kwargs) -> None:
         """
         Writes data to file.
 
